@@ -22,11 +22,11 @@ CAPE::Utils - A helpful library for with CAPE.
 
 =head1 VERSION
 
-Version 2.1.0
+Version 2.2.0
 
 =cut
 
-our $VERSION = '2.1.0';
+our $VERSION = '2.2.0';
 
 =head1 SYNOPSIS
 
@@ -1538,10 +1538,6 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=CAPE-Utils>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/CAPE-Utils>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/CAPE-Utils>
